from installclass import BaseInstallClass
import rhpl
from rhpl.translate import N_,_
from constants import *
from flags import flags
import os
import iutil
import types
try:
    import wibbleinstnum
except ImportError:
    instnum = None

import logging
log = logging.getLogger("anaconda")

# custom installs are easy :-)
class InstallClass(BaseInstallClass):
    # name has underscore used for mnemonics, strip if you dont need it
    id = "enterprise"
    name = N_("Oracle Linux Server")
    _description = N_("The default installation of %s includes a set of "
                     "software applicable for general internet usage. "
                     "What additional tasks would you like your system "
                     "to include support for?") 
    _descriptionFields = (productName,)
    sortPriority = 10000
    allowExtraRepos = False

    log.info("Examining %s" % id)

    taskMap = {'server'        : [(N_("Software Development"), 
                                   ["development-libs", "development-tools",
                                    "gnome-software-development", 
                                    "x-software-development"],),
                                  (N_("Web server"), ["web-server"],),
				  (N_("Virtualization"), ["xen"],),
				  (N_("Clustering"), ["clustering"],),
				  (N_("Storage Clustering"),
					["cluster-storage"])]

             }

    def setInstallData(self, anaconda):
	BaseInstallClass.setInstallData(self, anaconda)
        BaseInstallClass.setDefaultPartitioning(self, anaconda.id.partitions,
                                                CLEARPART_TYPE_LINUX)

    def setGroupSelection(self, anaconda):
        grps = anaconda.backend.getDefaultGroups(anaconda)
        map(lambda x: anaconda.backend.selectGroup(x), grps)

    def setSteps(self, dispatch):
	BaseInstallClass.setSteps(self, dispatch);
	dispatch.skipStep("partition")
	dispatch.skipStep("regkey", skip = 0)        

    # for rhel, we're putting the metadata under productpath
    def getPackagePaths(self, uri):
        rc = {}
        for (name, path) in self.repopaths.items():
            if not type(uri) == types.ListType:
                uri = [uri,]
            if not type(path) == types.ListType:
                path = [path,]

            lst = []
            for i in uri:
                for p in path:
                    lst.append("%s/%s" % (i, p))

            rc[name] = lst

        log.info("package paths is/are %s" %(rc,))
        return rc

#    def handleRegKey(self, key, intf, interactive = True):
#        self.repopaths = { "base": "%s" %(productPath,) }
#        self.tasks = self.taskMap[productPath.lower()]
#        self.installkey = key
#
#        log.info("repopaths is %s" %(self.repopaths,))
#
#        if inum is not None:
#            # make sure the base products match
#            if inum.get_product_string().lower() != productPath.lower():
#                raise ValueError, "Installation number incompatible with media"
#
#            for name, path in inum.get_repos_dict().items():
#                # virt is only supported on i386/x86_64.  so, let's nuke it
#                # from our repo list on other arches unless you boot with
#                # 'linux debug'
#                if name.lower() == "virt" and ( \
#                        rhpl.getArch() not in ("x86_64","i386")
#                        and not flags.debug):
#                    continue
#                self.repopaths[name.lower()] = path
#                log.info("Adding %s repo" % (name,))
#
#
#        log.info("repopaths is %s" %(self.repopaths,))

    def __init__(self, expert):
	BaseInstallClass.__init__(self, expert)


        self.repopaths = { "virt": "VT",
                           "cluster": "Cluster",
			   "clusterstorage": "ClusterStorage",
			   "base": "%s" % (productPath,)
                         }

	self.tasks = self.taskMap[productPath.lower()]

	log.info("Using RHupdates version\n")
